@@ -2,4 +2,4 @@ name = "switchbee"
 
 from .const import SWITCHBEE_BRAND
 
-__all__ = ["api", "device"]
+__all__ = ["api", "device", "central_unit"]
